@@ -55,7 +55,7 @@ GPG_ID_FILE_PATH = os.getenv(
 )
 try:
     with open(GPG_ID_FILE_PATH) as f:
-        GPG_ID = f.read()
+        GPG_ID = f.read().strip()
 except FileNotFoundError:
     GPG_ID = None
 
