@@ -3,7 +3,6 @@ import os
 from typing import Any, List, Optional
 
 import click
-import requests
 
 from . import (
     GPG_ID,
@@ -119,6 +118,7 @@ def cli(ctx):
 @click.pass_context
 @click.argument("title")
 @click.argument("feed")
+@click.option("-r", "--reverse", is_flag=True, help="Reverse order of episodes.")
 @catch_pod_store_errors
 @require_store
 @git_add_and_commit(
@@ -127,7 +127,7 @@ def cli(ctx):
     params=["title"],
 )
 @save_store_changes
-def add(ctx: click.Context, title: str, feed: str):
+def add(ctx: click.Context, title: str, feed: str, reverse: bool):
     """Add a podcast to the store.
 
     TITLE: title that will be used for tracking in the store
@@ -135,7 +135,7 @@ def add(ctx: click.Context, title: str, feed: str):
     FEED: rss url for updating podcast episode data
     """
     store = ctx.obj
-    store.podcasts.add(title=title, feed=feed)
+    store.podcasts.add(title=title, feed=feed, reverse_episode_order=reverse)
 
 
 @cli.command()
@@ -227,8 +227,47 @@ def download(
                 with click.progressbar(download, length=download.length) as bar:
                     for _ in bar:
                         pass
-        except requests.ConnectTimeout:
-            click.secho("Error: timed out when downloading episode.", fg="red")
+        except Exception as err:
+            click.secho(f"Error when downloading episode: {err}", fg="red")
+
+
+@cli.command()
+@click.pass_context
+@click.argument("podcast")
+@click.option("-f", "--feed", help="Update feed URL.")
+@click.option("-r", "--reverse", is_flag=True, help="Reverse episode order in feed.")
+@click.option(
+    "-d", "--do-not-reverse", is_flag=True, help="Do not reverse episode order in feed."
+)
+@catch_pod_store_errors
+@require_store
+@git_add_and_commit(
+    secure_git_mode_message="Added podcast.",
+    message="Edited podcast: {podcast!r}.",
+    params=["podcast"],
+)
+@save_store_changes
+def edit(
+    ctx: click.Context,
+    podcast: str,
+    feed: Optional[str] = None,
+    reverse: bool = False,
+    do_not_reverse: bool = False,
+):
+    store = ctx.obj
+    podcast = store.podcasts.get(podcast)
+
+    if feed:
+        podcast.feed = feed
+        click.echo(f"Podcast feed updated: {feed}")
+
+    if reverse and not podcast.reverse_episode_order:
+        podcast.reverse_episode_order = True
+        click.echo("Podcast updated: reverse episode order.")
+
+    if do_not_reverse and podcast.reverse_episode_order:
+        podcast.reverse_episode_order = False
+        click.echo("Podcast updated: do not reverse episode order.")
 
 
 @cli.command()
@@ -653,8 +692,8 @@ def refresh(
         click.echo(f"Refreshing {podcast.title}.")
         try:
             podcast.refresh()
-        except requests.ConnectTimeout:
-            click.secho("Error: timed out when reading RSS feed.", fg="red")
+        except Exception as err:
+            click.secho(f"Error when updating RSS feed: {err}", fg="red")
 
 
 @cli.command()
@@ -864,6 +903,30 @@ def unencrypt_store(ctx: click.Context):
     click.echo("Store was unencrypted.")
 
 
+@cli.command()
+@click.pass_context
+@click.option(
+    "-f",
+    "--force",
+    is_flag=True,
+    callback=abort_if_false,
+    expose_value=False,
+    prompt="Are you sure you want to unlock the pod store?",
+    help="Skip the confirmation prompt.",
+)
+@catch_pod_store_errors
+@require_store
+@git_add_and_commit(
+    secure_git_mode_message="Unlocked the store.", message="Unlocked the store."
+)
+def unlock(ctx: click.Context):
+    """Unlock the store manually. Could be necessary if a command that modifies store
+    state crashed without exiting gracefully."""
+    store = ctx.obj
+    store.unlock()
+    click.echo("Store was unlocked.")
+
+
 def main() -> None:
     """Run the Click application."""
     cli()
